==> text_cleaner_for_py-1.4.0.tar.gz: text_cleaner_for_py-1.4.0/setup.py <==
from setuptools import find_packages, setup

setup(
    name="text_cleaner_for_py",
    version="1.4.0",
    packages=find_packages(),
    install_requires=[
        "pyspellchecker>=0.7.2",
        "PyPDF2>=3.0.0",
        "python-docx>=0.8.11",
        "nltk>=3.8.1",
        "emoji>=2.8.0",
        "beautifulsoup4>=4.12.2",
        "redis>=5.0.1",
        "torch>=2.0.0",
        "numpy>=1.24.0",
        "pytest>=7.4.0",
        "pytest-asyncio>=0.21.1",
        "pytest-cov>=4.1.0",
        "pytest-benchmark>=4.0.0",
        "pytest-mock>=3.11.1",
        "pytest-timeout>=2.1.0",
        "pytest-xdist>=3.3.1",
        "pytest-sugar>=0.9.7",
        "pytest-html>=4.1.1",
        "pytest-metadata>=3.0.0",
        "pytest-env>=1.1.1",
        "pytest-randomly>=3.12.0",
        "pytest-repeat>=0.9.1",
        "pytest-rerunfailures>=12.0",
    ],
    author="Roberto Lima",
    author_email="robertolima@example.com",
    description="Uma biblioteca Python para limpeza e processamento de texto",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/seu-usuario/text_cleaner",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Text Processing :: General",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.8",
    include_package_data=True,
    license="MIT",
    project_urls={
        "Homepage": "https://github.com/robertolima-dev/text-cleaner-for-py", # noqa501
        "Repository": "https://github.com/robertolima-dev/text-cleaner-for-py", # noqa501
        "Issues": "https://github.com/robertolima-dev/text-cleaner-for-py/issues", # noqa501
    },
)

==> text_cleaner_for_py-1.4.1.tar.gz: text_cleaner_for_py-1.4.1/setup.py <==
from setuptools import find_packages, setup

setup(
    name="text_cleaner_for_py",
    version="1.4.1",
    packages=find_packages(),
    install_requires=[
        "pyspellchecker>=0.7.2",
        "PyPDF2>=3.0.0",
        "python-docx>=0.8.11",
        "nltk>=3.8.1",
        "emoji>=2.8.0",
        "beautifulsoup4>=4.12.2",
        "redis>=5.0.1",
        "torch>=2.0.0",
        "numpy>=1.24.0",
        "pytest>=7.4.0",
        "pytest-asyncio>=0.21.1",
        "pytest-cov>=4.1.0",
        "pytest-benchmark>=4.0.0",
        "pytest-mock>=3.11.1",
        "pytest-timeout>=2.1.0",
        "pytest-xdist>=3.3.1",
        "pytest-sugar>=0.9.7",
        "pytest-html>=4.1.1",
        "pytest-metadata>=3.0.0",
        "pytest-env>=1.1.1",
        "pytest-randomly>=3.12.0",
        "pytest-repeat>=0.9.1",
        "pytest-rerunfailures>=12.0",
    ],
    author="Roberto Lima",
    author_email="robertolima@example.com",
    description="​💬​ Uma biblioteca Python para limpeza e processamento de texto",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/seu-usuario/text_cleaner",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Text Processing :: General",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    python_requires=">=3.8",
    include_package_data=True,
    license="MIT",
    project_urls={
        "Homepage": "https://github.com/robertolima-dev/text-cleaner-for-py", # noqa501
        "Repository": "https://github.com/robertolima-dev/text-cleaner-for-py", # noqa501
        "Issues": "https://github.com/robertolima-dev/text-cleaner-for-py/issues", # noqa501
    },
)
